@@ -65,6 +65,13 @@ correctly. A secondary goal is not to blow up on ill-formed regular
 expressions. The correct identification and characterization of
 ill-formed regular expressions is B<not> a goal of this package.
 
+This policy attempts to track features in development releases as well
+as public releases. However, features added in a development release and
+then removed before the next production release B<will not> be tracked,
+and any functionality relating to such features B<will be removed>. The
+issue here is the potential re-use (with different semantics) of syntax
+that did not make it into the production release.
+
 =head1 METHODS
 
 This class provides the following public methods. Methods not documented
@@ -80,11 +87,11 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Node };
 
-use Params::Util 0.25 qw{ _INSTANCE };
 use PPIx::Regexp::Lexer ();
+use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.008';
+our $VERSION = '0.015';
 
 =head2 new
 
@@ -198,7 +205,7 @@ any objects specified are removed from the cache.
     sub new_from_cache {
 	my ( $class, $content, %args ) = @_;
 
-	_INSTANCE( $content, 'PPI::Element' )
+	__instance( $content, 'PPI::Element' )
 	    or return $class->new( $content, %args );
 
 	$DISABLE_CACHE and return $class->new( $content, %args );
@@ -222,8 +229,8 @@ any objects specified are removed from the cache.
 
 	if ( @args ) {
 	    foreach my $obj ( @args ) {
-		if ( _INSTANCE( $obj, __PACKAGE__ ) &&
-		    _INSTANCE( ( my $parent = $obj->source() ),
+		if ( __instance( $obj, __PACKAGE__ ) &&
+		    __instance( ( my $parent = $obj->source() ),
 			'PPI::Element' ) ) {
 		    delete $cache{ refaddr( $parent ) };
 		}
@@ -484,6 +491,18 @@ represent a character class. Similarly, curly brackets containing
 B<only> a bareword or an interpolation are a subscript; otherwise they
 represent a quantifier.
 
+=head2 Changes in Syntax
+
+Sometimes the introduction of new syntax changes the way a regular
+expression is parsed. For example, the C<\v> character class was
+introduced in Perl 5.9.5. But it did not represent a syntax error prior
+to that version of Perl, it was simply parsed as C<v>. So
+
+ $ perl -le 'print "v" =~ m/\v/ ? "yes" : "no"'
+
+prints "yes" under Perl 5.8.9, but "no" under 5.10.0. C<PPIx::Regexp>
+generally assumes the more modern parse in cases like this.
+
 =head2 Static Parsing
 
 It is well known that Perl can not be statically parsed. That is, you
