@@ -36,16 +36,19 @@ use warnings;
 use base qw{ PPIx::Regexp::Token::CharClass };
 
 use PPIx::Regexp::Constant qw{
-    $COOKIE_CLASS $MINIMUM_PERL $TOKEN_LITERAL $TOKEN_UNKNOWN
+    COOKIE_CLASS MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
 };
-use Readonly;
 
-our $VERSION = '0.008';
+our $VERSION = '0.015';
 
 {
 
-    Readonly::Hash my %introduced => (
-	'\N'	=> 5.011,
+    my %introduced = (
+	'\h'	=> '5.009005',	# Before this, parsed as 'h'
+	'\v'	=> '5.009005',	# Before this, parsed as 'v'
+	'\H'	=> '5.009005',	# Before this, parsed as 'H'
+	'\N'	=> '5.011',	# Before this, an error.
+	'\V'	=> '5.009005',	# Before this, parsed as 'V'
     );
 
     sub perl_version_introduced {
@@ -54,9 +57,15 @@ our $VERSION = '0.008';
 	if ( defined( my $minver = $introduced{$content} ) ) {
 	    return $minver;
 	}
-	$content =~ m/ \A \\ [Pp] .*? [\s=-] /smx
-	    and return 5.011003;
-	return $MINIMUM_PERL;
+	if ( $content =~ m/ \A \\ [Pp] /smxg ) {
+	    # I must have read perl5113delta and thought this
+	    # represented the change they were talking about, but I sure
+	    # don't see it now. So, until things become clearer ...
+#	    $content =~ m/ \G .*? [\s=-] /smxgc
+#		and return '5.011003';
+	    return '5.006001';
+	}
+	return MINIMUM_PERL;
     }
 
 }
@@ -64,11 +73,11 @@ our $VERSION = '0.008';
 sub __PPIX_TOKENIZER__regexp {
     my ( $class, $tokenizer, $character ) = @_;
 
-    my $in_class = $tokenizer->cookie( $COOKIE_CLASS );
+    my $in_class = $tokenizer->cookie( COOKIE_CLASS );
 
     if ( $character eq '.' ) {
 	$in_class
-	    and return $tokenizer->make_token( 1, $TOKEN_LITERAL );
+	    and return $tokenizer->make_token( 1, TOKEN_LITERAL );
 	return 1;
     }
 
@@ -83,7 +92,7 @@ sub __PPIX_TOKENIZER__regexp {
 	    # As of Perl 5.11.5, [\N] is a fatal error.
 	    '\\N' eq $match
 		and return $tokenizer->make_token(
-		    $accept, $TOKEN_UNKNOWN );
+		    $accept, TOKEN_UNKNOWN );
 	    # \R is not recognized inside a character class. It
 	    # eventually ends up as a literal.
 	    '\\R' eq $match and return;
