@@ -43,17 +43,17 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-use Params::Util 0.25 qw{ _INSTANCE };
 use PPI::Document;
+use PPIx::Regexp::Util qw{ __instance };
 
-our $VERSION = '0.008';
+our $VERSION = '0.015';
 
 sub _new {
     my ( $class, $content ) = @_;
     ref $class and $class = ref $class;
 
     my $self = {};
-    if ( _INSTANCE( $content, 'PPI::Document' ) ) {
+    if ( __instance( $content, 'PPI::Document' ) ) {
 	$self->{ppi} = $content;
     } elsif ( ref $content ) {
 	return;
@@ -75,6 +75,11 @@ sub content {
     }
 }
 
+sub perl_version_introduced {
+#   my ( $self ) = @_;
+    return '5.005';	# When (?{...}) introduced.
+}
+
 =head2 ppi
 
 This convenience method returns the L<PPI::Document|PPI::Document>
@@ -87,7 +92,8 @@ sub ppi {
     if ( exists $self->{ppi} ) {
 	return $self->{ppi};
     } elsif ( exists $self->{content} ) {
-	return ( $self->{ppi} = PPI::Document->new( \{$self->{content}}) );
+	return ( $self->{ppi} = PPI::Document->new(
+		\($self->{content}), readonly => 1 ) );
     } else {
 	return;
     }
@@ -101,18 +107,10 @@ sub __PPIX_TOKENIZER__regexp {
 
     $character eq '{' or return;
 
-    my $doc = $tokenizer->ppi_document()
+    my $offset = $tokenizer->find_matching_delimiter()
 	or return;
 
-    my $block = ( $doc->find_first( 'PPI::Structure::Block' ) ||
-	$doc->find_first( 'PPI::Structure::Constructor' ) )
-	or return;
-
-    $block->isa( 'PPI::Structure::Constructor' )
-	and $block->content() !~ m/ \A \{ /smx
-	and return;
-
-    return length ( $block->content() );
+    return $offset + 1;	# to include the closing delimiter.
 }
 
 1;
