@@ -35,23 +35,41 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::Reference };
 
-use PPIx::Regexp::Constant qw{ $RE_CAPTURE_NAME };
+use PPIx::Regexp::Constant qw{ RE_CAPTURE_NAME };
 
-our $VERSION = '0.005';
+our $VERSION = '0.015';
+
+sub perl_version_introduced {
+    my ( $self ) = @_;
+    ( my $content = $self->content() ) =~ m/ \A [(] \d+ [)] \z /smx
+	and return '5.005';
+    return '5.009005';
+}
 
 my @recognize = (
     [ qr{ \A \( (?: ( \d+ ) | R (\d+) ) \) }smx,
 	{ is_named => 0 } ],
     [ qr{ \A \( R \) }smx,
-    { is_named => 0, capture => '0' } ],
-    [ qr{ \A \( (?: < ( $RE_CAPTURE_NAME ) > |
-	    ' ( $RE_CAPTURE_NAME ) ' |
-	    R & ( $RE_CAPTURE_NAME ) ) \) }smx,
+	{ is_named => 0, capture => '0' } ],
+    [ qr{ \A \( (?: < ( @{[ RE_CAPTURE_NAME ]} ) > |
+	    ' ( @{[ RE_CAPTURE_NAME ]} ) ' |
+	    R & ( @{[ RE_CAPTURE_NAME ]} ) ) \) }smxo,
 	{ is_named => 1} ],
     [ qr{ \A \( DEFINE \) }smx,
 	{ is_named => 0, capture => '0' } ],
 );
 
+# This must be implemented by tokens which do not recognize themselves.
+# The return is a list of list references. Each list reference must
+# contain a regular expression that recognizes the token, and optionally
+# a reference to a hash to pass to make_token as the class-specific
+# arguments. The regular expression MUST be anchored to the beginning of
+# the string.
+sub __PPIX_TOKEN__recognize {
+    return @recognize;
+}
+
+
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
@@ -82,7 +100,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, Thomas R. Wyant, III
+Copyright (C) 2009-2010, Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
