@@ -36,7 +36,27 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::Modifier PPIx::Regexp::Token::GroupType };
 
-our $VERSION = '0.005';
+use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
+
+our $VERSION = '0.015';
+
+{
+
+    my %perl_version_introduced = (
+	'?:'	=> MINIMUM_PERL,
+    );
+
+    sub perl_version_introduced {
+	my ( $self ) = @_;
+	my $content = $self->content();
+	exists $perl_version_introduced{$content}
+	    and return $perl_version_introduced{$content};
+	my $ver = $self->SUPER::perl_version_introduced();
+	$ver > 5.005 and return $ver;
+	return '5.005';
+    }
+
+}
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -46,10 +66,13 @@ sub __PPIX_TOKENIZER__regexp {
 
     # Note that the optional escapes are because any of the
     # non-open-bracket punctuation characters might be our delimiter.
-    if ( my $accept = $tokenizer->find_regexp(
-	    qr{ \A \\? \? [[:lower:]]* \\? -? [[:lower:]]* \\? : }smx ) ) {
-	return $accept;
-    }
+    my $accept;
+    $accept = $tokenizer->find_regexp(
+	qr{ \A \\? [?] [[:lower:]]* \\? -? [[:lower:]]* \\? : }smx )
+	and return $accept;
+    $accept = $tokenizer->find_regexp(
+	qr{ \A \\? [?] \^ [[:lower:]]* \\? : }smx )
+	and return $accept;
 
     return;
 }
@@ -69,7 +92,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, Thomas R. Wyant, III
+Copyright (C) 2009-2010, Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
